.. _dg-example_dg_common:

dg/example_dg_common.py
=======================

**Description**


Functions common to DG examples




:download:`source code </../sfepy/examples/dg/example_dg_common.py>`

.. literalinclude:: /../sfepy/examples/dg/example_dg_common.py

